clear all

scrsz = get(0,'ScreenSize');
figure('Position',[1 scrsz(4) scrsz(3)*0.8 scrsz(4)*.6])
format long;
textsize =18;

alphavals = 0:0.01:1;


%% Predator-prey
subplot(241)
hold on

IEvals = importdata('Specialist_PanelA_P_indirecteffect.txt');

plot(alphavals,-IEvals,'-k','LineWidth',3)

set(gca,'ycolor','k','FontSize',textsize)
set(gca,'Box','on')
xlabel('Interspecific competition','FontSize',textsize,'Color','w')
ylabel({'Indirect Effect Between';'Predators'},'FontSize',textsize)
ylim([-0.5 1])
xlim([0 1])
set(gca,'XTick',[0 0.5 1])
set(gca,'YTick',[-1 -0.5 0 0.5 1])
title('A: Predators')

%% Density Dependent Direct Transmission- symmetric eij
subplot(242)
hold on

IEvals1 = importdata('Specialist_PanelB_I_indirecteffect_eij0.txt');
IEvals2 = importdata('Specialist_PanelB_I_indirecteffect_eij1.txt');
IEvals3 = importdata('Specialist_PanelB_I_indirecteffect_eij05.txt');
IEvals4 = importdata('Specialist_PanelB_I_indirecteffect_eij15.txt');

plot(alphavals,-IEvals1,'--k','LineWidth',3)
plot(alphavals,-IEvals2,'-k','LineWidth',3)
plot(alphavals,-IEvals3,'-b','LineWidth',3)
plot(alphavals,-IEvals4,'-r','LineWidth',3)


set(gca,'ycolor','k','FontSize',textsize)
set(gca,'Box','on')
xlabel('Interspecific competition','FontSize',textsize,'Color','w')
ylabel('Inf. Host Classes','FontSize',textsize)
ylim([-0.5 1])
xlim([0 1])
set(gca,'XTick',[0 0.5 1])
set(gca,'YTick',[-1 -0.5 0 0.5 1])
title('B: Direct Trans.')

%% Density Dependent Direct Transmission - asymmetric eij
subplot(243)
hold on

IEvals2 = importdata('Specialist_PanelC_I_indirecteffect_eij1.txt');
IEvals3 = importdata('Specialist_PanelC_I_indirecteffect_eij05.txt');
IEvals4 = importdata('Specialist_PanelC_I_indirecteffect_eij25.txt');

plot(alphavals,-IEvals2,'-k','LineWidth',3)
plot(alphavals,-IEvals3,'-b','LineWidth',3)
plot(alphavals(1:80),-IEvals4(1:80),'-r','LineWidth',3)
plot(alphavals(82:end),-IEvals4(82:end),'-r','LineWidth',3)


set(gca,'ycolor','k','FontSize',textsize)
set(gca,'Box','on')
xlabel('Interspecific competition','FontSize',textsize,'Color','w')
ylabel('Inf. Host Classes','FontSize',textsize)
ylim([-0.5 1])
xlim([0 1])
set(gca,'XTick',[0 0.5 1])
set(gca,'YTick',[-1 -0.5 0 0.5 1])
title('C: Direct Trans.')



%% Frequency Dependent Direct Transmission 1
subplot(244)
hold on

IEvals = importdata('Specialist_PanelD_I_indirecteffect.txt');

plot(alphavals,-IEvals,'-k','LineWidth',3)

set(gca,'ycolor','k','FontSize',textsize)
set(gca,'Box','on')
xlabel('Interspecific competition','FontSize',textsize,'Color','w')
ylabel('Inf. Host Classes','FontSize',textsize)
ylim([-2 4])
xlim([0 1])
set(gca,'XTick',[0 0.5 1])
set(gca,'YTick',[-2 0 2 4])
title('D: Direct Trans.')


%% Environmental Transmission - I-I indirect effects
subplot(245)
hold on

IEvals1 = importdata('Specialist_PanelE_I_indirecteffect_eij0.txt');
IEvals2 = importdata('Specialist_PanelE_I_indirecteffect_eij1.txt');
IEvals3 = importdata('Specialist_PanelE_I_indirecteffect_eij05.txt');
IEvals4 = importdata('Specialist_PanelE_I_indirecteffect_eij15.txt');

plot(alphavals,-IEvals1,'--k','LineWidth',3)
plot(alphavals,-IEvals2,'-k','LineWidth',3)
plot(alphavals,-IEvals3,'-b','LineWidth',3)
plot(alphavals,-IEvals4,'-r','LineWidth',3)


set(gca,'ycolor','k','FontSize',textsize)
set(gca,'Box','on')
xlabel('Interspecific competition','FontSize',textsize)
ylabel({'Indirect Effect Between';'Inf. Host Classes'},'FontSize',textsize)
ylim([-0.5 1])
xlim([0 1])
set(gca,'XTick',[0 0.5 1])
set(gca,'YTick',[-1 -0.5 0 0.5 1])
title('E: Env. Trans.')

%% Environmental Transmission - P-P indirect effects
subplot(246)
hold on

IEvals1 = importdata('Specialist_PanelF_P_indirecteffect_eij0.txt');
IEvals2 = importdata('Specialist_PanelF_P_indirecteffect_eij1.txt');
IEvals3 = importdata('Specialist_PanelF_P_indirecteffect_eij05.txt');
IEvals4 = importdata('Specialist_PanelF_P_indirecteffect_eij15.txt');

plot(alphavals,-IEvals1,'--k','LineWidth',3)
plot(alphavals,-IEvals2,'-k','LineWidth',3)
plot(alphavals,-IEvals3,'-b','LineWidth',3)
plot(alphavals,-IEvals4,'-r','LineWidth',3)

set(gca,'ycolor','k','FontSize',textsize)
set(gca,'Box','on')
xlabel('Interspecific competition','FontSize',textsize)
ylabel('Propagules','FontSize',textsize)
ylim([-0.075 0.15])
xlim([0 1])
set(gca,'XTick',[0 0.5 1])
set(gca,'YTick',[-0.2 -0.1 0 0.1 0.2])
title('F: Env. Trans.')



%% Environmental Transmission with Uptake - I-I indirect effects
subplot(247)
hold on

IEvals2 = importdata('Specialist_PanelG_I_indirecteffect_eij1.txt');
IEvals3 = importdata('Specialist_PanelG_I_indirecteffect_eij05.txt');
IEvals4 = importdata('Specialist_PanelG_I_indirecteffect_eij15.txt');

plot(alphavals,-IEvals2,'-k','LineWidth',3)
plot(alphavals,-IEvals3,'-b','LineWidth',3)
plot(alphavals(1:80),-IEvals4(1:80),'-r','LineWidth',3)
plot(alphavals(82:end),-IEvals4(82:end),'-r','LineWidth',3)

set(gca,'ycolor','k','FontSize',textsize)
set(gca,'Box','on')
xlabel('Interspecific competition','FontSize',textsize)
ylabel('Inf. Host Classes','FontSize',textsize)
ylim([-0.5 1])
xlim([0 1])
set(gca,'XTick',[0 0.5 1])
set(gca,'YTick',[-1 0 1])
title('G: Env. Trans.')

%% Environmental Transmission with Uptake - P-P indirect effects
subplot(248)
hold on

IEvals2 = importdata('Specialist_PanelH_P_indirecteffect_eij1.txt');
IEvals3 = importdata('Specialist_PanelH_P_indirecteffect_eij05.txt');
IEvals4 = importdata('Specialist_PanelH_P_indirecteffect_eij15.txt');



plot(alphavals,-IEvals2,'-k','LineWidth',3)
plot(alphavals,-IEvals3,'-b','LineWidth',3)
plot(alphavals(1:80),-IEvals4(1:80),'-r','LineWidth',3)
plot(alphavals(82:end),-IEvals4(82:end),'-r','LineWidth',3)


set(gca,'ycolor','k','FontSize',textsize)
set(gca,'Box','on')
xlabel('Interspecific competition','FontSize',textsize)
ylabel('Propagules','FontSize',textsize)
ylim([-1 2])
xlim([0 1])
set(gca,'XTick',[0 0.5 1])
set(gca,'YTick',[-2 -1 0 1 2])
title('H: Env. Trans.')

